/*
 * Copyright 2010, Red Hat, Inc. and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.zanata.rest;

import java.io.IOException;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.ext.Provider;

import org.jboss.resteasy.annotations.interception.ServerInterceptor;
import org.jboss.resteasy.spi.interception.MessageBodyReaderContext;
import org.jboss.resteasy.spi.interception.MessageBodyReaderInterceptor;
import org.zanata.rest.service.RestUtils;
import org.zanata.util.ServiceLocator;

/**
 * Validates all objects being read from any of the REST endpoints with the
 * Hibernate validator. If there is a validation failure it throws a
 * WebApplicationException with a BAD_REQUEST (400) code.
 *
 * @author Carlos Munoz <a
 *         href="mailto:camunoz@redhat.com">camunoz@redhat.com</a>
 */
@Provider
@ServerInterceptor
public class HibernateValidationInterceptor implements
        MessageBodyReaderInterceptor {
    @Override
    public Object read(MessageBodyReaderContext context) throws IOException,
            WebApplicationException {
        Object unmarshalledMssgBody = context.proceed();

        RestUtils restUtils =
                ServiceLocator.instance().getInstance(RestUtils.class);
        restUtils.validateEntity(unmarshalledMssgBody);

        return unmarshalledMssgBody;
    }

}
